@@ -7,14 +7,10 @@ from climetlab.normalize import normalize
 
 from ..config import baseurl
 
-__version__ = "0.1.9"
+__version__ = "0.2.2"
 
 _terms_of_use = """By downloading data from this dataset, you agree to the terms and conditions defined at
 
-    https://github.com/Climdyn/climetlab-eumetnet-postprocessing-benchmark/blob/main/LICENSE
-
-and
-
     https://github.com/Climdyn/climetlab-eumetnet-postprocessing-benchmark/blob/main/DATA_LICENSE
 
 If you do not agree with such terms, do not download the data. """
@@ -25,7 +21,7 @@ class StaticField(Dataset):
 
     _BASEURL = baseurl
 
-    _static_parameters = ["landu", "mterh"]
+    _static_parameters = ["landu", "mterh", "z"]
 
     @normalize("parameter", _static_parameters)
     def __init__(self, parameter):
@@ -34,5 +30,7 @@ class StaticField(Dataset):
             url = self._BASEURL + 'data/static/land_cover.nc'
         elif parameter == "mterh":
             url = self._BASEURL + 'data/static/model_altitude.nc'
+        elif parameter == "z":
+            url = self._BASEURL + 'data/static/000z.nc'
 
         self.source = cml.load_source("url", url)
